# Systems of linear ordinary differential equations

## Homogeneous systems of linear ODEs with constant coefficients

Let $\mathbb{K} = \mathbb{R} \lor \mathbb{C}$, $n \in \mathbb{N}$ and $A \in \mathbb{R}^{n \times n}$. Seek differentiable functions $y:\mathbb{R} \to \mathbb{K}^n$ such that 

$$
\mathbf{\dot y}(t) = A \mathbf{y}(t), \qquad t \in \mathbb{R}
$$

The solutions from a linear space, therefore the general solutions can be written as,

$$
\mathbf{y}(t) = \sum_{k=1}^n c_k \mathbf{y}_k(t), \qquad c_k \in \mathbb{K}
$$

where $\{\mathbf{y_1}, \dots, \mathbf{y_n}\}$ is a linear independent set of solutions, i.e. the basis of the solutions space.

Assume now that $A$ is diagonalizable, and let $\{\mathbf{v_1}, \dots, \mathbf{v_n}\}$ be a basis of $\mathbb{K}^n$ consisting of eigenvectors of A.

$$
AV = VD, \qquad \text{with } D = \begin{pmatrix} \lambda_1 & & \\ & \ddots & \\ & & \lambda_n \end{pmatrix}
$$

then $A = VDV^{-1}$, let $\mathbf{z}(t) = V^{-1} \mathbf{y}(t)$

$$
\begin{array}{ll}
&\mathbf{\dot z} = V^{-1} \mathbf{\dot y} = V^{-1} A \mathbf{y} = V^{-1} V D V^{-1} = D \mathbf{z}, \\
& \mathbf{\dot z} = D \mathbf{z} \implies \mathbf{z}(t) = \mathbf{c} e^{\lambda t}.
\end{array}
$$

Obtaining the general solution

$$\mathbf{y}(t) = V \mathbf{z}(t) = \sum_{k=1}^n c_k \mathbf{v_k} e^{\lambda_k t}.
$$

## Inhomogeneous systems of linear ODEs with constant coefficients

Let $I \subseteq \mathbb{R}$ be an interval, $\mathbf{f}: I \to \mathbb{R}$ continuous. Find functions $\mathbf{y}: I \to \mathbb{R}^n$ such that 

$$
\mathbf{\dot y}(t) = A \mathbf{y}(t) + \mathbf{f}(t), \qquad t \in I. \qquad (*)
$$

*Theorem*: let $\mathbf{y}_p: I \to \mathbb{R}^n$ a particular solution for $(*)$ and $\mathbf{y}_h$ the general solution to the homegeneous system. Then the general solutions of the inhomogeneous system $(*)$ is given by

$$
\mathbf{y}(t) = \mathbf{y}_p(t) + \mathbf{y}_h(t), \qquad t \in I
$$

<details>
<summary><em>Proof</em>:</summary>

similar to 1d case, will be added later.

</details>
<br>

### Method of variation of parameters

Let $\{\mathbf{y_1}, \dotsc, \mathbf{y_n}\}$ be a basis for the solution space of the homogeneous system. Ansatz:

$$
\mathbf{y}_p(t) = \sum_{k=1}^n c_k(t) \mathbf{y}_k(t) = (\mathbf{y}_1, \dots, \mathbf{y}_n) \begin{pmatrix} c_1(t) \\ \vdots \\ c_n(t) \end{pmatrix} = Y(t) \mathbf{c}(t),
$$

where $c_1(t), \dots, c_n(t): I \to \mathbb{R}$ are to be determined. 

Then: 

$$
\begin{align*}
\mathbf{\dot y}_p &= \sum_{k=1}^n \dot c_k(t) \mathbf{y}_k(t) + \sum_{k=1}^n c_k(t) \mathbf{\dot y}_k(t), \\
                  &= \sum_{k=1}^n \dot c_k(t) \mathbf{y}_k(t) + A \sum_{k=1}^n c_k(t) \mathbf{y}_k(t), \\
                  &= Y(t) \mathbf{\dot c}(t) + A \mathbf{y}_p(t).
\end{align*}
$$

Demanding that: $Y(t) \mathbf{\dot c}(t) = \mathbf{f}(t)$ is the Wronskian. Then $\mathbf{\dot c}(t) = Y^{-1}(t) \mathbf{f}(t) \iff Y(t)$ is nonsingular. Then solve for $\mathbf{c}(t)$. 