# Maps

## Definition

> *Definition*: a relation $f$ from a set $A$ to a set $B$ is called a map or function from $A$ to $B$ if for each $a \in A$ there is one and only one $b \in B$ with $afb$. 
>
> * To indicate that $f$ is a map from $A$ to $B$ we may write $f:A \to B$.
> * If $a \in A$ and $b \in B$ is the unique element with $afb$ then we may write $b=f(a)$. 
> * The set of all maps from $A$ to $B$ is denoted by $B^A$.
> * A partial map $f$ from a $A$ to $B$ with the property that for each $a \in A$ there is at most one $b \in B$ with $afb$. 

For example, let $f: \mathbb{R} \to \mathbb{R}$ with $f(x) = \sqrt{x}$ for all $x \in \mathbb{R}$ is a partial map, since not all of $\mathbb{R}$ is mapped.

<br>

> *Proposition*: let $f: A \to B$ and $g: B \to C$ be maps, then the composition $g$ after $f$: $g \circ f = f;g$ is a map from $A$ to $C$. 
> 
> ??? note "*Proof*:"
> 
>   Let $a \in A$ then $g(f(a))$ is an element in $C$ in relation $f;g$ with $a$. If $c \in C$ is an element in $C$ that is in relation $f;g$ with $a$, then there is a $b \in B$ with $afb$ and $bgc$. But then, as $f$ is a map, $b=f(a)$ and as $g$ is a map $c=g(b)$. Hence $c=g(b)=g(f(a))$ is the unique element in $C$ which is in relation $g \circ f$ with $a$. 

<br>

> *Definition*: Let $f: A \to B$ be a map.
> 
> * The set $A$ is called the *domain* of $f$ and the set $B$ the *codomain*. 
> * If $a \in A$ then the element $b=f(a)$ is called the image of $a$ under $f$. 
> * The subset of $B$ consisting of the images of the elements of $A$ under $f$ is called the image or range of $f$ and is denoted by $\text{Im}(f)$. 
> * If $a \in A$ amd $b=f(a)$ then the element $a$ is called a pre-image of $b$. The set of all pre-images of $b$ is denoted by $f^{-1}(b)$. 

Notice that $b$ can have more than one pre-image. Indeed if $f: \mathbb{R} \to \mathbb{R}$ is given by $f(x) = x^2$ for all $x \in \mathbb{R}$, then both $-2$ and $2$ are pre-images of $4$.

If $A'$ is a subset of $A$ then the image of $A'$ under $f$ is the set $f(A') = \{f(a) \;|\; a \in A'\}$, so $\text{Im}(f) = f(A)$. 

If $B'$ is a subet of $B$ then the pre-image of $B'$, denoted by $f^{-1}(B') is the set of elements $a$ from $A$ that are mapped to an element $b$ of $B'$.

<br>

> *Theorem*: let $f: A \to B$ be a map.
>
> * If $A' \subseteq A$, then $f^{-1}(f(A')) \supseteq A'$.
> * If $B' \subseteq B$, then $f(f^{-1}(B')) \subseteq B'$.
>
> ??? note "*Proof*:"
>
>   Let $a' \in A'$, then $f(a') \in f(A')$ and hence $a' \in f^{-1}(f(A'))$. Thus $A' \subseteq f^{-1}(f(A'))$.
>
>   Let $a \in f^{-1}(B')$, then $f(a) \in B'$. Thus $f(f^{-1}(B')) \subseteq B'$.